==> segatex_suite-1.4.tgz: segatex_suite-1.4/segatex_audit2allow.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qlayout.h>
#include <qcheckbox.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qradiobutton.h>
#include <qtextedit.h>
#include <qprocess.h>
//#####################
#include <unistd.h>
#include <sys/types.h>
#include <pwd.h>

#include "segatex_audit2allow.h"
#include "segatex_audit2allow_process.h"

//#include <iostream>
//using namespace std;

//default constructor
SegatexAudit2allow::SegatexAudit2allow(QWidget *parent, const char *name): QDialog(parent, name)
{
		setCaption(tr("audit2allow(only root can do this)"));
		lastreloadCheckBox = new QCheckBox(tr("read input only after the last reload"), this);
		requiresCheckBox = new QCheckBox(tr("generate require statements for rules"), this);
		referenceCheckBox = new QCheckBox(tr("generate refpolicy style output"), this);
		verboseCheckBox = new QCheckBox(tr("explain genetated output"), this);
		explainCheckBox = new QCheckBox(tr("fully explain genetated output"), this);
		//targetedCheckBox->setChecked(true);
		//strictCheckBox->setChecked(true);
		//mlsCheckBox->setChecked(true);
		//passwordLineEdit = new QLineEdit( this );
		//passwordLineEdit->setEchoMode(QLineEdit::Password);
		audit2allowButton = new QPushButton(tr("&audit2allow"), this);
		closeButton = new QPushButton(tr("&Close"), this);
		audit2allowButton->setDefault(true);

		connect(audit2allowButton, SIGNAL(clicked()), this, SLOT(audit2allow_clicked()));
		connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));

		QVBoxLayout *leftLayout = new QVBoxLayout;
		leftLayout->addWidget(lastreloadCheckBox);
		leftLayout->addWidget(requiresCheckBox);
		leftLayout->addWidget(referenceCheckBox);
		leftLayout->addWidget(verboseCheckBox);
		leftLayout->addWidget(explainCheckBox);

		QVBoxLayout *rightLayout = new QVBoxLayout;
		//rightLayout->addWidget(passwordLineEdit);
		rightLayout->addWidget(audit2allowButton);
		rightLayout->addWidget(closeButton);
		rightLayout->addStretch(1);

		QHBoxLayout *mainLayout = new QHBoxLayout(this);
		mainLayout->setMargin(11);
		mainLayout->setSpacing(6);
		mainLayout->addLayout(leftLayout);
		mainLayout->addLayout(rightLayout);
		//needs here to be declared for window newly opened unless segmentation fault occurs
		selinux_audit2allow_process = 0;
}
/*connects signal to close this window when yum process window's close button is clicked*/
void SegatexAudit2allow::audit2allow_clicked()
{
	if(!selinux_audit2allow_process) {
		selinux_audit2allow_process = new SegatexAudit2allowProcess(this);
		connect(selinux_audit2allow_process, SIGNAL(audit2allow_prosess_close_button_clicked()), this, SLOT(close()));
		connect(closeButton, SIGNAL(clicked()), selinux_audit2allow_process, SLOT(close()));
	}
	selinux_audit2allow_process->show();
	selinux_audit2allow_process->raise();
	selinux_audit2allow_process->setActiveWindow();
}
/*unused*/
unsigned long  SegatexAudit2allow::getuid_uid_value()
{
	struct passwd *passwd; /* man getpwuid */
	unsigned long uid_value;
	passwd = getpwuid ( getuid()); /* Get the uid of the running processand use it to get a record from /etc/passwd */
	uid_value = (unsigned long) getpwuid(getuid())->pw_uid;
	/*
	printf("\n The Real User Name is %s ", passwd->pw_gecos);
	printf("\n The Login Name is %s ", passwd->pw_name);
	printf("\n The Home Directory is %s", passwd->pw_dir);
	printf("\n The Login Shell is %s ", passwd->pw_shell);
	printf("\n The Passwd is %s ", getpwuid(getuid()) >pw_passwd);
	printf("\n The uid is %lu ", (unsigned long) getpwuid(getuid())->pw_uid);
	printf("\n The gid is %lu \n\n", (unsigned long) getpwuid(getuid())->pw_gid);
	*/
	//cout << "getuid_uid_value" << uid_value << endl;

	return uid_value;
}

==> segatex_suite-2.1.tgz: segatex_suite-2.1/segatex_audit2allow.cpp <==
/*
 * segatex SELinux tool.
 *
 * Copyright (C) 2007 Shintaro Fujiwara 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * */

#include <qlayout.h>
#include <qcheckbox.h>
#include <qlineedit.h>
#include <qpushbutton.h>
#include <qradiobutton.h>
#include <qtextedit.h>
#include <qprocess.h>
//#####################
#include <unistd.h>
#include <sys/types.h>
#include <pwd.h>

#include "segatex_audit2allow.h"
#include "segatex_audit2allow_process.h"

//#include <iostream>
//using namespace std;

//default constructor
SegatexAudit2allow::SegatexAudit2allow(QWidget *parent, const char *name): QDialog(parent, name)
{
		setCaption(tr("audit2allow(only root can do this)"));
		lastreloadCheckBox = new QCheckBox(tr("read input only after the last reload"), this);
		referenceCheckBox = new QCheckBox(tr("generate refpolicy style output"), this);
		verboseCheckBox = new QCheckBox(tr("explain genetated output"), this);
		explainCheckBox = new QCheckBox(tr("fully explain genetated output"), this);
		//targetedCheckBox->setChecked(true);
		//strictCheckBox->setChecked(true);
		//mlsCheckBox->setChecked(true);
		//passwordLineEdit = new QLineEdit( this );
		//passwordLineEdit->setEchoMode(QLineEdit::Password);
		audit2allowButton = new QPushButton(tr("&audit2allow"), this);
		closeButton = new QPushButton(tr("&Close"), this);
		audit2allowButton->setDefault(true);

		connect(audit2allowButton, SIGNAL(clicked()), this, SLOT(audit2allow_clicked()));
		connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));

		QVBoxLayout *leftLayout = new QVBoxLayout;
		leftLayout->addWidget(lastreloadCheckBox);
		leftLayout->addWidget(referenceCheckBox);
		leftLayout->addWidget(verboseCheckBox);
		leftLayout->addWidget(explainCheckBox);

		QVBoxLayout *rightLayout = new QVBoxLayout;
		//rightLayout->addWidget(passwordLineEdit);
		rightLayout->addWidget(audit2allowButton);
		rightLayout->addWidget(closeButton);
		rightLayout->addStretch(1);

		QHBoxLayout *mainLayout = new QHBoxLayout(this);
		mainLayout->setMargin(11);
		mainLayout->setSpacing(6);
		mainLayout->addLayout(leftLayout);
		mainLayout->addLayout(rightLayout);
		//needs here to be declared for window newly opened unless segmentation fault occurs
		selinux_audit2allow_process = 0;
		selinux_audit2allow_process_e = 0;
		selinux_audit2allow_process_l = 0;
		selinux_audit2allow_process_r = 0;
		selinux_audit2allow_process_v = 0;
}
/*connects signal to close this window when process window's close button is clicked*/
void SegatexAudit2allow::audit2allow_clicked()
{
		//-l -R -v -e //1111
		//-l -R -v//1110
		//-l -R -e//1101
		//-l -R//1100
		//-l -v -e//1011
		//-l -v//1010
		//-l -e//1001	
		//-l//1000
		//-R -v -e//111
		//-R -v//110
		//-R -e//101
		//-R//100
		//-v -e//11
		//-v//10
		//-e//1
		//no_option//0
		selinux_audit2allow_process = new SegatexAudit2allowProcess(this);
		connect(selinux_audit2allow_process, SIGNAL(audit2allow_prosess_close_button_clicked()), this, SLOT(close()));
		connect(closeButton, SIGNAL(clicked()), selinux_audit2allow_process, SLOT(close()));
		selinux_audit2allow_process->show();
		selinux_audit2allow_process->raise();
		selinux_audit2allow_process->setActiveWindow();

	if(lastreloadCheckBox->isOn()){
		if(referenceCheckBox->isOn()){
			if(verboseCheckBox->isOn()){
				if(explainCheckBox->isOn()){
					//-l -R -v -e
					selinux_audit2allow_process->audit2allow_base_process(1111);
				}else{
					//-l -R -v
					selinux_audit2allow_process->audit2allow_base_process(1110);
				}
			}else{
				if(explainCheckBox->isOn()){
					//-l -R -e
					selinux_audit2allow_process->audit2allow_base_process(1101);
				}else{
					//-l -R
					selinux_audit2allow_process->audit2allow_base_process(1100);
				}	
			}
		}else{
			if(verboseCheckBox->isOn()){
				if(explainCheckBox->isOn()){
					//-l -v -e
					selinux_audit2allow_process->audit2allow_base_process(1011);
				}else{
					//-l -v
					selinux_audit2allow_process->audit2allow_base_process(1010);
				}
			}else{
				if(explainCheckBox->isOn()){
					//-l -e	
					selinux_audit2allow_process->audit2allow_base_process(1001);
				}else{
					//-l
					selinux_audit2allow_process->audit2allow_base_process(1000);
				}
			}
		}
	}else{
		if(referenceCheckBox->isOn()){
			if(verboseCheckBox->isOn()){
				if(explainCheckBox->isOn()){
					//-R -v -e
					selinux_audit2allow_process->audit2allow_base_process(111);
				}else{
					//-R -v
					selinux_audit2allow_process->audit2allow_base_process(110);
				}
			}else{
				if(explainCheckBox->isOn()){
					//-R -e
					selinux_audit2allow_process->audit2allow_base_process(101);
				}else{
					//-R
					selinux_audit2allow_process->audit2allow_base_process(100);
				}	
			}
		}else{
			if(verboseCheckBox->isOn()){
				if(explainCheckBox->isOn()){
					//-v -e
					selinux_audit2allow_process->audit2allow_base_process(11);
				}else{
					//-v
					selinux_audit2allow_process->audit2allow_base_process(10);
				}
			}else{
				if(explainCheckBox->isOn()){
					//-e
					selinux_audit2allow_process->audit2allow_base_process(1);
				}else{
					//no_option
					selinux_audit2allow_process->audit2allow_base_process(0);
				}	
			}
		}
	}
}
/*unused*/
unsigned long  SegatexAudit2allow::getuid_uid_value()
{
	struct passwd *passwd; /* man getpwuid */
	unsigned long uid_value;
	passwd = getpwuid ( getuid()); /* Get the uid of the running processand use it to get a record from /etc/passwd */
	uid_value = (unsigned long) getpwuid(getuid())->pw_uid;
	/*
	printf("\n The Real User Name is %s ", passwd->pw_gecos);
        connect (selinux_audit2allow, SIGNAL(explainChecked()), this, SLOT(setX()));

	printf("\n The Login Name is %s ", passwd->pw_name);
	printf("\n The Home Directory is %s", passwd->pw_dir);
	printf("\n The Login Shell is %s ", passwd->pw_shell);
	printf("\n The Passwd is %s ", getpwuid(getuid()) >pw_passwd);
	printf("\n The uid is %lu ", (unsigned long) getpwuid(getuid())->pw_uid);
	printf("\n The gid is %lu \n\n", (unsigned long) getpwuid(getuid())->pw_gid);
	*/
	//cout << "getuid_uid_value" << uid_value << endl;

	return uid_value;
}
